pub struct GroupsProcessor<T, E, L, C = ()> { /* private fields */ }Available on crate feature
processor only.Expand description
Processor for groups operations.
Implementations
Sourceimpl<T, E, L, C> GroupsProcessor<T, E, L, C>where
T: Serialize + for<'de> Deserialize<'de>,
E: Extensions + Extension<GroupsArgs<C>> + Extension<L>,
L: LogId,
C: Conditions + Serialize + for<'a> Deserialize<'a>,
impl<T, E, L, C> GroupsProcessor<T, E, L, C>where
T: Serialize + for<'de> Deserialize<'de>,
E: Extensions + Extension<GroupsArgs<C>> + Extension<L>,
L: LogId,
C: Conditions + Serialize + for<'a> Deserialize<'a>,
pub fn new(store: SqliteStore) -> Self
Sourcepub async fn process<SID>(
&self,
id: &SID,
topic: &T,
operation: &Operation<E>,
) -> Result<(), GroupsProcessorError<C>>where
SID: for<'a> Deserialize<'a> + Serialize,
pub async fn process<SID>(
&self,
id: &SID,
topic: &T,
operation: &Operation<E>,
) -> Result<(), GroupsProcessorError<C>>where
SID: for<'a> Deserialize<'a> + Serialize,
Process a groups operation.
Processed operations are first partially ordered, and only processed on the auth groups state if all their dependencies have been met. If other operations become “ready” by this one, then they will be all processed in order.
If an operation which does not contain the required groups extension is processed then it is ignored. Groups messages which are not yet present in the operation store are inserted.