pub struct Access<C = ()> {
pub conditions: Option<C>,
pub level: AccessLevel,
}Expand description
A level of access with optional conditions which can be assigned to an actor.
Access can be used to understand the rights of an actor to perform actions (request data, write data, etc..) within a certain data set. Custom conditions can be defined by the user in order to introduce domain specific access boundaries or integrate with another access token.
For example, a condition to model access boundaries using paths could be introduced where having access to “/public” gives you access to “/public/stuff” and “/public/other/stuff” but not “/private” or “/private/stuff”.
Fields
conditions: Option<C>level: AccessLevelImplementations
Sourceimpl<C> Access<C>
impl<C> Access<C>
Sourcepub fn with_conditions(self, conditions: C) -> Self
pub fn with_conditions(self, conditions: C) -> Self
Attach conditions to an access level.