pub struct GroupsExtensionArgs<C = ()> {
pub group_id: VerifyingKey,
pub action: GroupAction<VerifyingKey, C>,
pub dependencies: Vec<Hash>,
}Expand description
Additional arguments which can be attached to a p2panda operation in their extensions.
Fields
group_id: VerifyingKeyaction: GroupAction<VerifyingKey, C>dependencies: Vec<Hash>Trait Implementations
Sourceimpl<C: Clone> Clone for GroupsExtensionArgs<C>
impl<C: Clone> Clone for GroupsExtensionArgs<C>
Sourcefn clone(&self) -> GroupsExtensionArgs<C>
fn clone(&self) -> GroupsExtensionArgs<C>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<C: Debug> Debug for GroupsExtensionArgs<C>
impl<C: Debug> Debug for GroupsExtensionArgs<C>
Sourceimpl<'de, C> Deserialize<'de> for GroupsExtensionArgs<C>where
C: Deserialize<'de>,
impl<'de, C> Deserialize<'de> for GroupsExtensionArgs<C>where
C: Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl<C: Eq> Eq for GroupsExtensionArgs<C>
Sourceimpl<C: PartialEq> PartialEq for GroupsExtensionArgs<C>
impl<C: PartialEq> PartialEq for GroupsExtensionArgs<C>
Sourcefn eq(&self, other: &GroupsExtensionArgs<C>) -> bool
fn eq(&self, other: &GroupsExtensionArgs<C>) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<C> Serialize for GroupsExtensionArgs<C>where
C: Serialize,
impl<C> Serialize for GroupsExtensionArgs<C>where
C: Serialize,
impl<C: PartialEq> StructuralPartialEq for GroupsExtensionArgs<C>