pub struct GroupsOperation<C = ()> {
pub id: Hash,
pub author: VerifyingKey,
pub dependencies: Vec<Hash>,
pub group_id: VerifyingKey,
pub action: GroupAction<VerifyingKey, C>,
}Expand description
Concrete groups operation type.
Fields
id: Hashdependencies: Vec<Hash>group_id: VerifyingKeyaction: GroupAction<VerifyingKey, C>Trait Implementations
Sourceimpl<C: Clone> Clone for GroupsOperation<C>
impl<C: Clone> Clone for GroupsOperation<C>
Sourcefn clone(&self) -> GroupsOperation<C>
fn clone(&self) -> GroupsOperation<C>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<C: Debug> Debug for GroupsOperation<C>
impl<C: Debug> Debug for GroupsOperation<C>
Sourceimpl<'de, C> Deserialize<'de> for GroupsOperation<C>where
C: Deserialize<'de>,
impl<'de, C> Deserialize<'de> for GroupsOperation<C>where
C: Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl<C: Eq> Eq for GroupsOperation<C>
Sourceimpl<C> Operation<VerifyingKey, Hash, C> for GroupsOperation<C>where
C: Conditions,
Implementation of groups Operation trait.
impl<C> Operation<VerifyingKey, Hash, C> for GroupsOperation<C>where
C: Conditions,
Implementation of groups Operation trait.
ID of the author of this operation.
Sourcefn dependencies(&self) -> Vec<Hash>
fn dependencies(&self) -> Vec<Hash>
Auth dependencies.
Sourcefn group_id(&self) -> VerifyingKey
fn group_id(&self) -> VerifyingKey
The id of the group the action applies to.
Sourcefn action(&self) -> GroupAction<VerifyingKey, C>
fn action(&self) -> GroupAction<VerifyingKey, C>
The group action.
Sourceimpl<C: PartialEq> PartialEq for GroupsOperation<C>
impl<C: PartialEq> PartialEq for GroupsOperation<C>
Sourcefn eq(&self, other: &GroupsOperation<C>) -> bool
fn eq(&self, other: &GroupsOperation<C>) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<C> Serialize for GroupsOperation<C>where
C: Serialize,
impl<C> Serialize for GroupsOperation<C>where
C: Serialize,
impl<C: PartialEq> StructuralPartialEq for GroupsOperation<C>