pub fn has_path<OP>(graph: &DiGraphMap<OP, ()>, from: OP, to: OP) -> boolwhere
OP: OperationId + Ord,Expand description
Return true if a linear path exists in the graph between from and to.
This indicates whether to is a successor of from.