GroupCrdtState

Struct GroupCrdtState 

pub struct GroupCrdtState<ID, OP, C, ORD>
where ID: IdentityHandle, OP: OperationId + Ord, ORD: Orderer<ID, OP, GroupControlMessage<ID, C>> + Debug, ORD::Operation: Clone,
{ pub inner: GroupCrdtInnerState<ID, OP, C, ORD::Operation>, pub orderer_y: ORD::State, }
State object for GroupCrdt containing an orderer state and the inner state.

Fields

inner: GroupCrdtInnerState<ID, OP, C, ORD::Operation>

Inner groups state.

orderer_y: ORD::State

State for the orderer.

Implementations

Source

impl<ID, OP, C, ORD> GroupCrdtState<ID, OP, C, ORD>
where ID: IdentityHandle, OP: OperationId + Ord, C: Conditions, ORD: Orderer<ID, OP, GroupControlMessage<ID, C>> + Debug, ORD::Operation: Clone,

pub fn new(orderer_y: ORD::State) -> Self

Instantiate a new state.

pub fn root_members(&self, group_id: ID) -> Vec<(GroupMember<ID>, Access<C>)>

Get all direct members of a group.

This method does not recurse into sub-groups, but rather returns only the direct group members and their access levels.

pub fn members(&self, group_id: ID) -> Vec<(ID, Access<C>)>

Get all transitive members of a group.

This method recurses into all sub-groups and returns a resolved list of individual group members and their access levels.

pub fn has_group(&self, group_id: ID) -> bool

Returns true if the passed group exists in the current state.

Source

impl<ID, OP, C, ORD> GroupCrdtState<ID, OP, C, ORD>
where ID: IdentityHandle + Ord + Display, OP: OperationId + Ord + Display, C: Conditions, ORD: Orderer<ID, OP, GroupControlMessage<ID, C>> + Clone + Debug, ORD::State: Clone, ORD::Operation: Clone,

pub fn display(&self, group_id: ID) -> String

Print an auth group graph in DOT format for visualizing the group operation DAG.