Module processor

Module processor 

Types and methods for ordering and processing groups operations.

Structs

GroupsArgs
Additional arguments which can be attached to a p2panda operation in their extensions.
GroupsOperation
Concrete groups operation type.
GroupsProcessor
Processor for groups operations.

Enums

GroupsProcessorError
Error types which can occur in the groups processor.